==> snapbelt-0.12.0-py2-none-any.whl: snapbelt/updater.py <==
"""SNAPtoolbelt Update Commands"""
import logging

from arghandler import ArgumentHandler

import pip

log = logging.getLogger(__name__)

PYPI_SERVER = "https://update.synapse-wireless.com/pypi"


def update(parser, context, args):
    """Update commands"""
    handler = ArgumentHandler()

    handler.set_subcommands({
        'check': check_for_updates,
        'install': install_updates
    })

    handler.run(args, context_fxn=lambda x: context)


def check_for_updates(parser, context, args):
    """Ask pip to check for updated toolbelt & dependencies"""
    handler = ArgumentHandler()
    handler.add_argument("--pre",
                         action="store_true",
                         help="Allow pre-release versions")

    args = handler.parse_args(args)

    if args.pre:
        pip.main(['list', '--pre', '--outdated', '--extra-index-url', PYPI_SERVER, 'snapbelt'])
    else:
        pip.main(['list', '--outdated', '--extra-index-url', PYPI_SERVER, 'snapbelt'])


def install_updates(parser, context, args):
    """Ask pip to upgrade toolbelt & dependencies"""
    handler = ArgumentHandler()
    handler.add_argument("--pre",
                         action="store_true",
                         help="Allow pre-release versions")

    args = handler.parse_args(args)

    if args.pre:
        pip.main(['install', '--pre', '--upgrade', '--extra-index-url', PYPI_SERVER, 'snapbelt'])
    else:
        pip.main(['install', '--upgrade', '--extra-index-url', PYPI_SERVER, 'snapbelt'])

==> snapbelt-0.13.0-py2-none-any.whl: snapbelt/updater.py <==
"""SNAPtoolbelt Update Commands"""
import logging

from arghandler import ArgumentHandler

import pip

log = logging.getLogger(__name__)

PYPI_SERVER = "https://update.synapse-wireless.com/pypi"


def update(parser, context, args):
    """Update commands"""
    handler = ArgumentHandler()

    handler.set_subcommands({
        'check': check_for_updates,
        'install': install_updates
    })

    handler.run(args, context_fxn=lambda x: context)


def check_for_updates(parser, context, args):
    """Ask pip to check for updated toolbelt & dependencies"""
    handler = ArgumentHandler()
    handler.add_argument("--pre",
                         action="store_true",
                         help="Allow pre-release versions")

    args = handler.parse_args(args)

    if args.pre:
        pip.main(['list', '--pre', '--outdated', '--extra-index-url',
                  PYPI_SERVER, 'snapbelt'])
    else:
        pip.main(['list', '--outdated', '--extra-index-url', PYPI_SERVER,
                  'snapbelt'])


def install_updates(parser, context, args):
    """Ask pip to upgrade toolbelt & dependencies"""
    handler = ArgumentHandler()
    handler.add_argument("--pre",
                         action="store_true",
                         help="Allow pre-release versions")

    args = handler.parse_args(args)

    if args.pre:
        pip.main(['install', '--pre', '--upgrade', '--extra-index-url',
                  PYPI_SERVER, 'snapbelt'])
    else:
        pip.main(['install', '--upgrade', '--extra-index-url', PYPI_SERVER,
                  'snapbelt'])
